@@ -75,7 +75,6 @@ calculate_pupil_xy (EyesApplet *eyes_applet,
 		    gint x, gint y,
 		    gint *pupil_x, gint *pupil_y, GtkWidget* widget)
 {
-        double angle;
         double sina;
         double cosa;
         double h;
@@ -174,10 +173,6 @@ about_cb (BonoboUIComponent *uic,
 	  EyesApplet        *eyes_applet,
 	  const gchar       *verbname)
 {
-	GdkPixbuf	 *pixbuf;
-	GError		 *error = NULL;
-	gchar		 *file;
-        
         static const gchar *authors [] = {
 		"Dave Camp <campd@oit.edu>",
 		NULL
@@ -190,44 +185,17 @@ about_cb (BonoboUIComponent *uic,
 		NULL
 	};
 
-	const gchar *translator_credits = _("translator_credits");
-
-	if (eyes_applet->about_dialog) {
-		gtk_window_set_screen (GTK_WINDOW (eyes_applet->about_dialog),
-				       gtk_widget_get_screen (GTK_WIDGET (eyes_applet->applet)));
-		
-		gtk_window_present (GTK_WINDOW (eyes_applet->about_dialog));
-		return;
-	}
-        
-	file = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, "gnome-eyes.png", FALSE, NULL);
-	pixbuf = gdk_pixbuf_new_from_file (file, &error);
-	g_free (file);
-	
-	if (error) {
-		g_warning (G_STRLOC ": cannot open %s: %s", file, error->message);
-		g_error_free (error);
-	}
-	
-        eyes_applet->about_dialog = gnome_about_new (
-		_("Geyes"), VERSION,
-		_("Copyright (C) 1999 Dave Camp"),
-		_("A goofy little xeyes clone for the GNOME panel."),
-		authors,
-		documenters,
-		strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
-		pixbuf);
-		
-	if (pixbuf)
-		gdk_pixbuf_unref (pixbuf);
-			
-	gtk_window_set_wmclass (GTK_WINDOW (eyes_applet->about_dialog), "geyes", "Geyes");
-	gtk_window_set_screen (GTK_WINDOW (eyes_applet->about_dialog),
-			       gtk_widget_get_screen (GTK_WIDGET (eyes_applet->applet)));
-	g_signal_connect (eyes_applet->about_dialog, "destroy",
-			  G_CALLBACK (gtk_widget_destroyed),
-			  &eyes_applet->about_dialog);
-	gtk_widget_show (eyes_applet->about_dialog);
+	gtk_show_about_dialog (NULL,
+		"name",		_("Geyes"),
+		"version",	VERSION,
+		"comments",	_("A goofy little xeyes clone for the GNOME "
+				  "panel."),
+		"copyright",	"\xC2\xA9 1999 Dave Camp",
+		"authors",	authors,
+		"documenters",	documenters,
+		"translator-credits",	_("translator-credits"),
+		"logo-icon-name",	"gnome-eyes-applet",
+		NULL);
 }
 
 static int
@@ -358,9 +326,6 @@ destroy_cb (GtkObject *object, EyesApplet *eyes_applet)
 		g_free (eyes_applet->pupil_filename);
 	eyes_applet->pupil_filename = NULL;
 	
-	if (eyes_applet->about_dialog)
-	  	gtk_widget_destroy (eyes_applet->about_dialog);
-
 	if (eyes_applet->prop_box.pbox)
 	  	gtk_widget_destroy (eyes_applet->prop_box.pbox);
 
@@ -379,8 +344,13 @@ help_cb (BonoboUIComponent *uic,
 		gtk_widget_get_screen (GTK_WIDGET (eyes_applet->applet)),
 		&error);
 
-	if (error) { /* FIXME: the user needs to see this */
-		g_warning ("help error: %s\n", error->message);
+	if (error) {
+		GtkWidget *dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE, 
+							    _("There was an error displaying help: %s"), error->message);
+		g_signal_connect (G_OBJECT (dialog), "response", G_CALLBACK (gtk_widget_destroy), NULL);
+		gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
+		gtk_window_set_screen (GTK_WINDOW (dialog), gtk_widget_get_screen (GTK_WIDGET (eyes_applet->applet)));
+		gtk_widget_show (dialog);
 		g_error_free (error);
 		error = NULL;
 	}
@@ -415,15 +385,13 @@ geyes_applet_fill (PanelApplet *applet)
 {
 	EyesApplet *eyes_applet;
 	
-	gtk_window_set_default_icon_name ("gnome-eyes");
+	gtk_window_set_default_icon_name ("gnome-eyes-applet");
 	panel_applet_set_flags (applet, PANEL_APPLET_EXPAND_MINOR);
 	
         eyes_applet = create_eyes (applet);
 
 	panel_applet_add_preferences (applet, "/schemas/apps/geyes/prefs", NULL);
 
-	eyes_applet->about_dialog = NULL;
-
         eyes_applet->timeout_id = gtk_timeout_add (
 		UPDATE_TIMEOUT, (GtkFunction) timer_cb, eyes_applet);
 			
