@@ -32,14 +32,13 @@
 #include <libgnome/gnome-help.h>
 #include <glade/glade.h>
 
-#include "eel-extension.h"
 #include "trashapplet.h"
 #include "trash-monitor.h"
 #include "xstuff.h"
 
 static GConfClient *client = NULL;
 
-G_DEFINE_TYPE(TrashApplet, trash_applet, PANEL_TYPE_APPLET);
+G_DEFINE_TYPE(TrashApplet, trash_applet, PANEL_TYPE_APPLET)
 
 static void     trash_applet_destroy            (GtkObject         *object);
 
@@ -129,7 +128,9 @@ trash_applet_init (TrashApplet *applet)
 	if (!client)
 		client = gconf_client_get_default ();
 
-	applet->size = panel_applet_get_size (PANEL_APPLET (applet));
+	applet->size = 0;
+	applet->new_size = 0;
+
 	switch (panel_applet_get_orient (PANEL_APPLET (applet))) {
 	case PANEL_APPLET_ORIENT_LEFT:
 	case PANEL_APPLET_ORIENT_RIGHT:
@@ -148,7 +149,6 @@ trash_applet_init (TrashApplet *applet)
 	gtk_container_add (GTK_CONTAINER (applet), applet->image);
 	gtk_widget_show (applet->image);
 	applet->icon_state = TRASH_STATE_UNKNOWN;
-	gtk_image_set_pixel_size (GTK_IMAGE (applet->image), applet->size);
 
 	/* create local trash directory if needed */
 	res = gnome_vfs_find_directory (NULL,
@@ -217,8 +217,8 @@ trash_applet_size_allocate (GtkWidget    *widget,
 		new_size = allocation->width;
 
 	if (new_size != applet->size) {
-		applet->size =  new_size;
-		gtk_image_set_pixel_size (GTK_IMAGE (applet->image), new_size);
+		applet->new_size = new_size;
+		trash_applet_queue_update (applet);
 	}
 
 	(* GTK_WIDGET_CLASS (trash_applet_parent_class)->size_allocate) (widget, allocation);
@@ -244,8 +244,8 @@ trash_applet_change_orient (PanelApplet       *panel_applet,
 		break;
 	}
 	if (new_size != applet->size) {
-		applet->size =  new_size;
-		gtk_image_set_pixel_size (GTK_IMAGE (applet->image), new_size);
+		applet->new_size = new_size;
+		trash_applet_queue_update (applet);
 	}
 
 	if (PANEL_APPLET_CLASS (trash_applet_parent_class)->change_orient)
@@ -286,6 +286,7 @@ trash_applet_change_background (PanelApplet               *panel_applet,
 	}
 }
 
+#define PANEL_ENABLE_ANIMATIONS "/apps/panel/global/enable_animations"
 static gboolean
 trash_applet_button_release (GtkWidget      *widget,
 			     GdkEventButton *event)
@@ -293,7 +294,8 @@ trash_applet_button_release (GtkWidget      *widget,
 	TrashApplet *applet = TRASH_APPLET (widget);
 
 	if (event->button == 1) {
-		xstuff_zoom_animate(widget, NULL);
+		if (gconf_client_get_bool (client, PANEL_ENABLE_ANIMATIONS, NULL))
+			xstuff_zoom_animate (widget, NULL);
 		trash_applet_open_folder (NULL, applet, NULL);
 		return TRUE;
 	}
@@ -352,7 +354,7 @@ trash_applet_drag_motion (GtkWidget      *widget,
 		applet->drag_hover = TRUE;
 		trash_applet_queue_update (applet);
 	}
-	gdk_drag_status (context, context->suggested_action, time_);
+	gdk_drag_status (context, GDK_ACTION_MOVE, time_);
 
 	return TRUE;
 }
@@ -375,6 +377,7 @@ trash_applet_update (gpointer user_data)
 	const char *new_icon;
 	GdkScreen *screen;
 	GtkIconTheme *icon_theme;
+	GdkPixbuf *pixbuf, *scaled;
 
 	applet->update_id = 0;
 
@@ -419,29 +422,46 @@ trash_applet_update (gpointer user_data)
 		new_icon = TRASH_ICON_FULL;
 	}
 
-	if (applet->image && applet->icon_state != new_state) {
+	if (applet->image && applet->new_size > 10 &&
+            (applet->icon_state != new_state ||
+	     applet->new_size != applet->size)) {
+                gint size;
+		applet->size = applet->new_size;
+		size = applet->size - 4;
+		screen = gtk_widget_get_screen (GTK_WIDGET (applet));
+		icon_theme = gtk_icon_theme_get_for_screen (screen);
 		/* not all themes have the "accept" variant */
 		if (new_state == TRASH_STATE_ACCEPT) {
-			screen = gtk_widget_get_screen (GTK_WIDGET (applet));
-			icon_theme = gtk_icon_theme_get_for_screen (screen);
 			if (!gtk_icon_theme_has_icon (icon_theme, new_icon))
 				new_icon = applet->is_empty
 					? TRASH_ICON_EMPTY
 					: TRASH_ICON_FULL;
 		}
-		gtk_image_set_from_icon_name (GTK_IMAGE (applet->image),
-					      new_icon, -1);
+		pixbuf = gtk_icon_theme_load_icon (icon_theme, new_icon, 
+						   size, 0, NULL);
+		if (!pixbuf)
+		    return FALSE;
+
+                if (gdk_pixbuf_get_width (pixbuf) != size ||
+                    gdk_pixbuf_get_height (pixbuf) != size) {
+			scaled = gdk_pixbuf_scale_simple (pixbuf, size, size, GDK_INTERP_BILINEAR);
+			g_object_unref (pixbuf);
+		 	pixbuf = scaled;
+		}
+
+		gtk_image_set_from_pixbuf (GTK_IMAGE (applet->image), pixbuf);
+		g_object_unref (pixbuf);
 	}
 
 	return FALSE;
 }
+
 static void
 trash_applet_queue_update (TrashApplet *applet)
 {
 	if (applet->update_id == 0) {
 		applet->update_id = g_idle_add (trash_applet_update, applet);
 	}
-
 }
 
 /* TODO - Must HIGgify this dialog */
@@ -479,60 +499,63 @@ error_dialog (TrashApplet *applet, const gchar *error, ...)
 
 static gint
 update_transfer_callback (GnomeVFSAsyncHandle *handle,
-                         GnomeVFSXferProgressInfo *progress_info,
-                         gpointer user_data)
+                          GnomeVFSXferProgressInfo *progress_info,
+                          gpointer user_data)
 {
-       /* UI updates here */
-       TrashApplet *applet = TRASH_APPLET (user_data);
+	TrashApplet *applet = TRASH_APPLET (user_data);
+	GladeXML *xml = applet->xml;
 
-       GladeXML *xml = applet->xml;
-       GtkWidget *location_label;
-       GtkWidget *file_label;
-       GtkWidget *progressbar;
+	if (progress_info->files_total != 0) {
+		GtkWidget *progressbar;
+		gdouble fraction;
+		gchar *progress_message;
 
-       gdouble fraction = 0.0;
-       gchar *index = "";
-       gchar *total = "";
-       gchar *progress_message = "";
+		progressbar = glade_xml_get_widget (xml, "progressbar");
 
-       gchar *from_location = NULL;
-       gchar *file = NULL;
-       GnomeVFSURI *uri;
+		fraction = (gulong) progress_info->file_index / (gulong) progress_info->files_total;
+		gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR (progressbar), fraction);
 
-       if (progress_info->files_total != 0)
-       {
-            fraction = (gulong) progress_info->file_index / (gulong) progress_info->files_total;
+		progress_message = g_strdup_printf (_("Removing item %d of %d"),
+						    progress_info->file_index,
+						    progress_info->files_total);
+		gtk_progress_bar_set_text (GTK_PROGRESS_BAR (progressbar),
+					   progress_message);
 
-	    index = g_strdup_printf ("%i", (gint) progress_info->file_index);
-	    total = g_strdup_printf ("%i", (gint) progress_info->files_total);
+		g_free (progress_message);
+	}
+
+	if (progress_info->source_name != NULL) {
+		GtkWidget *location_label;
+		GtkWidget *file_label;
+		GnomeVFSURI *uri;
+		gchar *short_name;
+		gchar *from_location;
+		gchar *file;
+
+		location_label = glade_xml_get_widget (xml, "location_label");
+		file_label = glade_xml_get_widget (xml, "file_label");
+
+		uri = gnome_vfs_uri_new (progress_info->source_name);
+
+		from_location = gnome_vfs_uri_extract_dirname (uri);
+
+		short_name = gnome_vfs_uri_extract_short_name (uri);
+		file = g_strdup_printf ("<i>%s %s</i>",
+                                        _("Removing:"),
+                                        short_name);
+		g_free (short_name);
+
+		gtk_label_set_markup (GTK_LABEL (location_label), from_location);
+		gtk_label_set_markup (GTK_LABEL (file_label), file);
+
+		g_free (from_location);
+		g_free (file);
+		gnome_vfs_uri_unref (uri);
        }
 
-       location_label = glade_xml_get_widget(xml, "location_label");
-       file_label = glade_xml_get_widget(xml, "file_label");
-       progressbar = glade_xml_get_widget(xml, "progressbar");
-
-       gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR (progressbar), fraction);
-
-       progress_message = g_strdup_printf (_("Removing item %s of %s"), index, total);
-       gtk_progress_bar_set_text (GTK_PROGRESS_BAR (progressbar), progress_message);
-       if (progress_info->source_name != NULL) {
-           uri = gnome_vfs_uri_new(progress_info->source_name);
-
-	   from_location = gnome_vfs_uri_extract_dirname (uri);
-
-	   file = g_strdup_printf (_("<i>Removing: %s</i>"), gnome_vfs_uri_extract_short_name (uri));
-       }
-
-       if (from_location != NULL)
-	       gtk_label_set_markup(GTK_LABEL (location_label), from_location);
-       if (file != NULL) 
-	       gtk_label_set_markup(GTK_LABEL (file_label), file);
-
-
        return 1;
 }
 
-
 /* this function is based on the one with the same name in
    libnautilus-private/nautilus-file-operations.c */
 #define NAUTILUS_PREFERENCES_CONFIRM_TRASH    "/apps/nautilus/preferences/confirm_trash"
@@ -613,7 +636,6 @@ trash_applet_do_empty (BonoboUIComponent *component,
 		       const gchar       *cname)
 {
 	GtkWidget *dialog;
-	GtkWidget *cancel_button;
 
 	GnomeVFSAsyncHandle *hnd;
 
@@ -647,19 +669,22 @@ trash_applet_open_folder (BonoboUIComponent *component,
 			  TrashApplet       *applet,
 			  const gchar       *cname)
 {
+	GdkScreen *screen;
+
 	/* Open the "trash:" URI with gnome-open */
-	gchar *argv[] = { "gnome-open", EEL_TRASH_URI, NULL };
+	gchar *argv[] = { "gnome-open", "trash:", NULL };
 	GError *err = NULL;
 	gboolean res;	
 
         g_return_if_fail (TRASH_IS_APPLET (applet));
 
-	res = g_spawn_async (NULL,
-			     argv, NULL,
-			     G_SPAWN_SEARCH_PATH,
-			     NULL, NULL,
-			     NULL,
-			     &err);
+	screen = gtk_widget_get_screen (GTK_WIDGET (applet));
+	res = gdk_spawn_on_screen (screen, NULL,
+			           argv, NULL,
+			           G_SPAWN_SEARCH_PATH,
+			           NULL, NULL,
+			           NULL,
+			           &err);
 	
 	if (! res) {
 		error_dialog (applet, _("Error while spawning nautilus:\n%s"),
@@ -718,7 +743,7 @@ trash_applet_show_about (BonoboUIComponent *component,
 		 "authors", authors,
 		 "documenters", documenters,
 		 "translator-credits", _("translator-credits"),
-		 "logo_icon_name", "gnome-fs-trash-full",
+		 "logo_icon_name", "user-trash-full",
 		 NULL);
 }
 
@@ -728,7 +753,7 @@ confirm_delete_immediately (GtkWidget *parent_view,
 			    gboolean all)
 {
 	GdkScreen *screen;
-	GtkWidget *dialog, *hbox, *vbox, *image, *label, *button;
+	GtkWidget *dialog, *hbox, *vbox, *image, *label;
 	gchar *str, *prompt, *detail;
 	int response;
 
@@ -828,7 +853,6 @@ trash_applet_drag_data_received (GtkWidget        *widget,
 	for (scan = g_list_first (list); scan; scan = g_list_next (scan)) {
 		GnomeVFSURI *source_uri = scan->data;
 		GnomeVFSURI *trash_uri, *target_uri;
-		gboolean is_local;
 		gchar *source_basename;
 
 		/* find the trash directory for this file */
